import contactBanner from '~/images/contact-banner.png'
import contactBg01 from '~/images/contact-bg-01.png'
import contactBg02 from '~/images/contact-bg-02.png'
import mapPoint from '~/images/map-point.svg'
import phoneColored from '~/images/phone-colored.svg'
import printer from '~/images/printer.svg'
import clock from '~/images/clock.svg'
import pageBg from '~/images/page-bg.png'

export default function Contact() {
  return (
    <div
      style={{
        backgroundImage: `url(${pageBg})`,
        backgroundSize: 'contain',
        backgroundPosition: 'top',
        backgroundRepeat: 'no-repeat'
      }}
    >
      <div className="relative">
        <div className="absolute inset-0 z-10 bg-secondary mix-blend-color opacity-70" />
        <img src={contactBanner} className="w-full" alt="" />
      </div>
      <div className="container mx-auto px-4 -mt-16 relative z-10">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-8">
          <div className="lg:p-8 p-4 rounded-2xl bg-white shadow-2xl space-y-4 lg:space-y-8">
            <div className="relative h-[150px] flex items-center justify-center rounded-2xl overflow-hidden p-4 text-center">
              <img
                src={contactBg01}
                className="absolute z-0 inset-0 object-cover size-full"
                alt=""
              />
              <span className="relative text-white text-xl lg:text-3xl font-bold">
                TOFAŞ TÜRK OTOMOBİL FABRİKASI A.Ş.
              </span>
            </div>
            <div className="space-y-4">
              <div className="flex items-start gap-2">
                <img src={mapPoint} alt="" />
                <span className="font-medium lg:text-lg">
                  Büyükdere Cad. No: 145, Tofaş Han, 34394 Zincirlikuyu, İstanbul
                </span>
              </div>
              <div className="flex items-start gap-2">
                <img src={phoneColored} alt="" />
                <span className="font-medium lg:text-lg">+90 (212) 275 33 90</span>
              </div>
              <div className="flex items-start gap-2">
                <img src={printer} alt="" />
                <span className="font-medium lg:text-lg">+90 (212) 275 39 88</span>
              </div>
            </div>
          </div>
          <div className="lg:p-8 p-4 rounded-2xl bg-white shadow-2xl space-y-4 lg:space-y-8">
            <div className="relative h-[150px] flex items-center justify-center rounded-2xl overflow-hidden p-4 text-center">
              <img
                src={contactBg02}
                className="absolute z-0 inset-0 object-cover size-full"
                alt=""
              />
              <span className="relative text-white text-xl lg:text-3xl font-bold">
                Opar Çağrı Merkezİ
              </span>
            </div>
            <div className="space-y-4">
              <div className="flex items-start gap-2">
                <img src={phoneColored} alt="" />
                <span className="font-medium lg:text-lg">0 216 454 15 52</span>
              </div>
              <div className="flex items-start gap-2">
                <img src={clock} alt="" />
                <span className="font-medium lg:text-lg">
                  Çalışma Saatleri: <br /> Hafta içi 08:00 - 18:00
                </span>
              </div>
            </div>
          </div>
        </div>
      </div>
      <div className="container mx-auto px-4 mt-10 lg:mt-28">
        <h3 className="text-xl lg:text-5xl text-center font-medium">
          Görüşleriniz Bizim İçin Değerli!
        </h3>
        <p className="lg:text-lg text-gray text-center mt-4">
          Bize önerilerinizi ileterek gelişimimize katkıda bulunabilir, karşılaştığınız sorunları
          bildirerek daha iyi hizmet almamıza yardımcı olabilirsiniz. Sizden gelen her geri bildirim
          bizim için önemli!
        </p>
        <div>
          <form action="#" method="POST" className="mx-auto mt-16 max-w-2xl sm:mt-20">
            <div className="grid grid-cols-1 gap-x-8 gap-y-6 lg:grid-cols-2">
              <div className="lg:col-span-2">
                <label htmlFor="email" className="block text-sm/6 font-semibold text-gray-900">
                  Kategori
                </label>
                <div className="mt-2.5">
                  <input
                    id="category"
                    name="category"
                    type="category"
                    autoComplete="category"
                    className="block w-full rounded-md bg-white px-3.5 py-2 text-base text-gray-900 outline-1 -outline-offset-1 outline-gray-300 placeholder:text-gray-400 focus:outline-2 focus:-outline-offset-2 focus:outline-indigo-600"
                  />
                </div>
              </div>
              <div>
                <label htmlFor="first-name" className="block text-sm/6 font-semibold text-gray-900">
                  Adınız
                </label>
                <div className="mt-2.5">
                  <input
                    id="first-name"
                    name="first-name"
                    type="text"
                    autoComplete="given-name"
                    className="block w-full rounded-md bg-white px-3.5 py-2 text-base text-gray-900 outline-1 -outline-offset-1 outline-gray-300 placeholder:text-gray-400 focus:outline-2 focus:-outline-offset-2 focus:outline-indigo-600"
                  />
                </div>
              </div>
              <div>
                <label htmlFor="last-name" className="block text-sm/6 font-semibold text-gray-900">
                  Soyadınız
                </label>
                <div className="mt-2.5">
                  <input
                    id="last-name"
                    name="last-name"
                    type="text"
                    autoComplete="family-name"
                    className="block w-full rounded-md bg-white px-3.5 py-2 text-base text-gray-900 outline-1 -outline-offset-1 outline-gray-300 placeholder:text-gray-400 focus:outline-2 focus:-outline-offset-2 focus:outline-indigo-600"
                  />
                </div>
              </div>
              <div>
                <label
                  htmlFor="phone-number"
                  className="block text-sm/6 font-semibold text-gray-900"
                >
                  Telefon Numaranız
                </label>
                <div className="mt-2.5">
                  <div className="flex rounded-md bg-white outline-1 -outline-offset-1 outline-gray-300 has-[input:focus-within]:outline-2 has-[input:focus-within]:-outline-offset-2 has-[input:focus-within]:outline-indigo-600">
                    <div className="grid shrink-0 grid-cols-1 focus-within:relative">
                      <select
                        id="country"
                        name="country"
                        autoComplete="country"
                        aria-label="Country"
                        className="col-start-1 row-start-1 w-full appearance-none rounded-md py-2 pr-7 pl-3.5 text-base text-gray-500 placeholder:text-gray-400 focus:outline-2 focus:-outline-offset-2 focus:outline-indigo-600 sm:text-sm/6"
                      >
                        <option>US</option>
                        <option>CA</option>
                        <option>EU</option>
                      </select>
                    </div>
                    <input
                      id="phone-number"
                      name="phone-number"
                      type="text"
                      placeholder="123-456-7890"
                      className="block min-w-0 grow py-1.5 pr-3 pl-1 text-base text-gray-900 placeholder:text-gray-400 focus:outline-none sm:text-sm/6"
                    />
                  </div>
                </div>
              </div>
              <div>
                <label htmlFor="email" className="block text-sm/6 font-semibold text-gray-900">
                  E-posta Adresiniz
                </label>
                <div className="mt-2.5">
                  <input
                    id="email"
                    name="email"
                    type="email"
                    autoComplete="email"
                    className="block w-full rounded-md bg-white px-3.5 py-2 text-base text-gray-900 outline-1 -outline-offset-1 outline-gray-300 placeholder:text-gray-400 focus:outline-2 focus:-outline-offset-2 focus:outline-indigo-600"
                  />
                </div>
              </div>

              <div className="lg:col-span-2">
                <label htmlFor="message" className="block text-sm/6 font-semibold text-gray-900">
                  Açıklama
                </label>
                <div className="mt-2.5">
                  <textarea
                    id="message"
                    name="message"
                    rows={4}
                    className="block w-full rounded-md bg-white px-3.5 py-2 text-base text-gray-900 outline-1 -outline-offset-1 outline-gray-300 placeholder:text-gray-400 focus:outline-2 focus:-outline-offset-2 focus:outline-indigo-600"
                    defaultValue={''}
                  />
                </div>
              </div>
            </div>
            <div className="mt-10">
              <button
                type="submit"
                className="block cursor-pointer w-full rounded-md bg-primary px-3.5 py-2.5 text-center text-sm font-semibold text-white shadow-xs hover:bg-secondary focus-visible:outline-2 focus-visible:outline-offset-2 focus-visible:outline-indigo-600"
              >
                Gönder
              </button>
            </div>
          </form>
        </div>
      </div>
    </div>
  )
}
